@@ -265,7 +265,7 @@ class Screen:
         raise NotImplementedError()
 
 @track("trace")
-class NVPair(Dictable):
+class nvpair(Dictable):
     '''
         Encapsulates a name-value pair. It is an implementation of **Dictable**.
 
@@ -297,7 +297,7 @@ class NVPair(Dictable):
 
 
 @track("trace")
-class Attr(NVPair):
+class attr(nvpair):
     '''
         A name-value pair with an associated optional tag name. It is an implementation of **Dictable**.
 
@@ -307,7 +307,7 @@ class Attr(NVPair):
             tag: Tag associated with this object
     '''
 
-    def __init__(self, *, name, value, tag=None):
+    def __init__(self, name, value, tag=None):
         super().__init__(name, value)
         self.__tag = tag
 
@@ -318,14 +318,13 @@ class Attr(NVPair):
 
 
 @track("trace")
-class NVPairs(Dictable):
+class nvpairs(Dictable):
     '''
         Encapsulates arbitrary name-value pairs. It is an implementation of **Dictable**.
 
         Keyword Arguments:
             **nvpairs: Arbitrary name-value pairs passed as keyword arguments.
     '''
-
     def __init__(self, **nvpairs):
         self.__kwargs = nvpairs
 
@@ -333,4 +332,37 @@ class NVPairs(Dictable):
         return self.__kwargs
 
 
+@track("trace")
+class withx(nvpairs):
+    '''
+        Encapsulates arbitrary name-value pairs. It is an implementation of **Dictable**.
+
+        This is to be used when using withx locators progammaitcally.
+
+        Keyword Arguments:
+            **nvpairs: Arbitrary name-value pairs passed as keyword arguments.
+    '''
+    pass
+
+
+@track("trace")
+class node(nvpairs):
+
+    def __init__(self, *attrs, **nvpairs):
+        self.__attrs = attrs
+        super().__init__(**nvpairs)
+
+    def _as_dict(self):
+        out_dict = dict()
+        d = super()._as_dict()
+        if 'attrs' in d:
+            out_dict.update(d['attrs'])
+        for attr in self.__attrs:
+            out_dict.update(attr.name, attr.value)
+        for k,v in d.items():
+            if k != 'attrs':
+                out_dict[k] = v
+        return out_dict
+
+
 NetworkPacketInfo = namedtuple("NetworkPacketInfo", "label request response sub_network_packets")
\ No newline at end of file
